Enum trust_dns_resolver::config::Protocol
[−]
[src]
pub enum Protocol {
Udp,
Tcp,
}The protocol on which a NameServer should be communicated with
Variants
UdpUDP is the traditional DNS port, this is generally the correct choice
TcpTCP can be used for large queries, but not all NameServers support it
Methods
impl Protocol[src]
pub fn is_datagram(&self) -> bool[src]
Returns true if this is a datagram oriented protocol, e.g. UDP
pub fn is_stream(&self) -> bool[src]
Returns true if this is a stream oriented protocol, e.g. TCP