pub struct NameServerStats {
pub addr: SocketAddr,
pub proto: Protocol,
pub failures: usize,
pub successes: usize,
pub success_streak: usize,
pub recent_errors: Vec<ResolveErrorKind>,
}Expand description
query statistics for a single name server.
Fields
addr: SocketAddrThe address of the name server.
proto: ProtocolThe protocol used to talk to the name server.
failures: usizeThe total number of lookup failures.
successes: usizeThe total number of lookup successes.
success_streak: usizeThe number of successful queries since the last failure.
recent_errors: Vec<ResolveErrorKind>The last N errors seen when querying this nameserver. Configured with
crate::config::NameServerConfig::num_retained_errors.