Struct trust_dns_resolver::config::ResolverConfig [] [src]

pub struct ResolverConfig { /* fields omitted */ }

Configuration for the upstream nameservers to use for resolution

Methods

impl ResolverConfig
[src]

[src]

Creates a new empty configuration

[src]

Create a ResolverConfig with all parts specified

Arguments

  • domain - domain of the entity querying results. If the Name being lookedup is not an FQDN, then this is the first part appended to attempt a lookup. ndots in in the ResolverOption does take precidence over this. Default should be . aka Name::root
  • search - additional search domains that are attempted if the Name is not found in domain, defaults to vec![]
  • name_servers - set of name servers to use for lookups, defaults are Google: 8.8.8.8, 8.8.4.4 and 2001:4860:4860::8888, 2001:4860:4860::8844

[src]

Returns the local domain

By default any names will be appended to all non-fully-qualified-domain names, and searched for after any ndots rules

[src]

Returns the search domains

These will be queried after any local domain and then in the order of the set of search domains

[src]

Add the configuration for a name server

[src]

Returns a reference to the name servers