Struct trust_dns_resolver::config::ResolverConfig
[−]
[src]
pub struct ResolverConfig { /* fields omitted */ }Configuration for the upstream nameservers to use for resolution
Methods
impl ResolverConfig[src]
fn new() -> Self[src]
Creates a new empty configuration
fn from_parts(
domain: Name,
search: Vec<Name>,
name_servers: Vec<NameServerConfig>
) -> Self[src]
domain: Name,
search: Vec<Name>,
name_servers: Vec<NameServerConfig>
) -> Self
Create a ResolverConfig with all parts specified
Arguments
domain- domain of the entity querying results. If theNamebeing lookedup is not an FQDN, then this is the first part appended to attempt a lookup.ndotsin in theResolverOptiondoes take precidence over this. Default should be.akaName::rootsearch- additional search domains that are attempted if theNameis not found indomain, defaults tovec![]name_servers- set of name servers to use for lookups, defaults are Google:8.8.8.8,8.8.4.4and2001:4860:4860::8888,2001:4860:4860::8844
fn domain(&self) -> &Name[src]
Returns the local domain
By default any names will be appended to all non-fully-qualified-domain names, and searched for after any ndots rules
fn search(&self) -> &[Name][src]
Returns the search domains
These will be queried after any local domain and then in the order of the set of search domains
fn add_name_server(&mut self, name_server: NameServerConfig)[src]
Add the configuration for a name server
fn name_servers(&self) -> &[NameServerConfig][src]
Returns a reference to the name servers