Struct trust_dns_resolver::config::ResolverOpts
[−]
[src]
pub struct ResolverOpts {
pub ndots: usize,
pub timeout: Duration,
pub attempts: usize,
pub validate: bool,
pub ip_strategy: LookupIpStrategy,
pub cache_size: usize,
pub use_hosts_file: bool,
// some fields omitted
}Configuration for the Resolver
Fields
ndots: usize
Sets the number of dots that must appear (unless it's a final dot representing the root)
that must appear before a query is assumted to include the TLD. The default is one, which
means that www would never be assumed to be a TLD, and would always be appended to either
the search
timeout: Duration
Specify the timeout for a request. Defaults to 5 seconds
attempts: usize
Number of attempts before giving up. Defaults to 2
validate: bool
Use DNSSec to validate the request
ip_strategy: LookupIpStrategy
The ip_strategy for the Resolver to use when lookup Ipv4 or Ipv6 addresses
cache_size: usize
Cache size is in number of records (some records can be large)
use_hosts_file: bool
Check /ect/hosts file before dns requery (only works for unix like OS)